@@ -18,7 +18,7 @@ use base qw(
     Weixin::Client::Base
 );
 
-our $VERSION = "2.0";
+our $VERSION = "2.1";
 
 sub new{
     my $class = shift;
@@ -82,11 +82,11 @@ sub new{
             return;
             
         });
-        #$self->{ua}->add_handler(
-        #    response_done => sub { my($response, $ua, $h) = @_;
-        #    #print substr($response->content,0,1000),"\n" if $response->header("content-type")=~/^text/;
-        #    return;
-        #});
+        $self->{ua}->add_handler(
+            response_done => sub { my($response, $ua, $h) = @_;
+            print substr($response->content,0,1000),"\n" if $response->header("content-type")=~/^text/;
+            return;
+        });
     }
     bless $self,$class;
     $self->prepare();
