@@ -3,6 +3,6 @@ sub _is_need_login{
     my $self = shift;
     my $api = "https://wx.qq.com/";
     my $data = $self->http_get($api,); 
-    return $data=~/\Q<div id="login_container" style="display:none;">\E/?0:1;
+    return $data=~/window\.MMCgi\s*=\s*{\s*isLogin\s*:\s*(!!"1")\s*}/s?0:1;
 }
 1;
