@@ -74,6 +74,10 @@ sub _parse_sync_data {
             $_->{FromId} = $_->{FromUserName};delete $_->{FromUserName};
             $_->{ToId} = $_->{ToUserName};delete $_->{ToUserName};
             @{$msg}{@key} = map {$_=encode_utf8($_);$_} @{$_}{@key};
+            eval{
+                require HTML::Entities;
+                $msg->{Content} = HTML::Entities::decode_entities($msg->{Content});
+            };
             $self->_add_msg($msg);
         }
     }
@@ -188,7 +192,11 @@ sub _add_msg{
                 $msg->{ToRemarkName} = $friend->{RemarkName};
             }
             elsif($msg->{Type} eq "chatroom_message"){
-                my $chatroom = $self->search_chatroom(ChatRoomId=>$msg->{ToId}) || $self->get_chatroom($msg->{ToId}) || {};
+                my $chatroom = $self->search_chatroom(ChatRoomId=>$msg->{ToId});
+                if(not defined $chatroom){
+                    $self->get_chatroom($msg->{ToId});
+                    $chatroom = $self->search_chatroom(ChatRoomId=>$msg->{ToId}) || {};
+                }
                 $msg->{FromNickName} = "我";
                 $msg->{FromRemarkName} = undef;
                 $msg->{FromUin} = $self->{_data}{user}{Uin};
@@ -212,7 +220,11 @@ sub _add_msg{
             elsif($msg->{Type} eq "chatroom_message"){
                 my ($chatroom_member_id,$content) = $msg->{Content}=~/^(\@.+):<br\/>(.*)/g; 
                 $msg->{Content} = $content;
-                my $member = $self->search_chatroom_member(ChatRoomId=>$msg->{FromId},Id=>$chatroom_member_id) || $self->get_chatroom($msg->{FromId}) ||  {};
+                my $member = $self->search_chatroom_member(ChatRoomId=>$msg->{FromId},Id=>$chatroom_member_id);
+                if(not defined $member){
+                    $self->get_chatroom($msg->{FromId});
+                    $member = $self->search_chatroom_member(ChatRoomId=>$msg->{FromId},Id=>$chatroom_member_id) || {};
+                }
                 $msg->{FromNickName} = $member->{NickName};
                 $msg->{FromId}       = $member->{Id};
                 $msg->{FromRemarkName} = undef;
